@@ -1,10 +1,10 @@
-# $Id: Apache.pm,v 1.4 2002/05/12 13:35:35 m_ilya Exp $
+# $Id: Apache.pm,v 1.7 2002/07/02 22:47:18 m_ilya Exp $
 
 package HTTP::WebTest::Plugin::Apache;
 
 =head1 NAME
 
-HTTP::WebTest::Plugin::Apache - Local web file tests plugin
+HTTP::WebTest::Plugin::Apache - Plugin for local web file tests
 
 =head1 SYNOPSIS
 
@@ -12,7 +12,7 @@ Not Applicable
 
 =head1 DESCRIPTION
 
-This plugin provides support for local web file test mode.  Apache
+This plugin supports local web file test mode.  Apache
 must be installed to run tests in this mode.
 
 =for pod_merge copy apache
@@ -577,9 +577,9 @@ sub DESTROY {
 	kill SIGTERM, $apache_pid
 	    or die "HTTP::WebTest: Can't kill Apache PID=$apache_pid: $!";
 
-	while(1) {
+	{
 	    my $pid = wait;
-	    last if $pid == -1 or $pid == $apache_pid;
+	    redo unless $pid == -1 or $pid == $apache_pid;
 	}
     }
 
@@ -593,10 +593,10 @@ sub DESTROY {
 
 Copyright (c) 2000-2001 Richard Anderson.  All rights reserved.
 
-Copyright (c) 2001,2002 Ilya Martynov.  All rights reserved.
+Copyright (c) 2001-2002 Ilya Martynov.  All rights reserved.
 
-This module is free software.  It may be used, redistributed and/or
-modified under the terms of the Perl Artistic License.
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
