@@ -1,4 +1,4 @@
-# $Id: HarnessReport.pm,v 1.5 2002/05/12 13:35:35 m_ilya Exp $
+# $Id: HarnessReport.pm,v 1.7 2002/06/21 06:48:16 richardanderson Exp $
 
 package HTTP::WebTest::Plugin::HarnessReport;
 
@@ -13,13 +13,14 @@ HTTP::WebTest::Plugin::HarnessReport - Test::Harness compatible reports
 
 =head1 DESCRIPTION
 
-This plugin creates L<Test::Harness|Test::Harness> compatible test
-reports.  This plugin is not loaded by default by
-L<HTTP::WebTest|HTTP::WebTest>.  To load it use global test parameter
+This plugin creates reports that are compatible with
+L<Test::Harness|Test::Harness>.
+By default, this plugin is not loaded by 
+L<HTTP::WebTest|HTTP::WebTest>.  To load it, use the global test parameter
 C<plugins>.
 
-Unless you want to get mix of outputs from default and this report
-plugins default report plugin should disabled.  See parameter
+Unless you want to get mix of outputs from the default report and this report,
+the default report plugin should be disabled.  See parameter
 C<default_report> (value C<no>).
 
 Test parameters C<plugins> and C<default_report> are documented in
@@ -89,10 +90,10 @@ sub report_test {
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001,2002 Ilya Martynov.  All rights reserved.
+Copyright (c) 2001-2002 Ilya Martynov.  All rights reserved.
 
-This module is free software.  It may be used, redistributed and/or
-modified under the terms of the Perl Artistic License.
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
